==> GenomeARTIST_v1.17b_src.zip: src/exenne/components/headerrenderer/MultilineHeaderRenderer.java <==
/*
 * To change this template, choose Tools | Templates
 * and open the template in the editor.
 */

package exenne.components.headerrenderer;

import java.awt.BorderLayout;
import java.awt.Color;
import java.awt.Component;
import java.io.BufferedReader;
import java.io.IOException;
import java.io.StringReader;
import java.util.Iterator;
import java.util.List;
import java.util.Vector;
import javax.swing.Icon;
import javax.swing.JLabel;
import javax.swing.JList;
import javax.swing.JPanel;
import javax.swing.JTable;
import javax.swing.ListCellRenderer;
import javax.swing.RowSorter;
import javax.swing.UIManager;
import javax.swing.table.TableCellRenderer;

/**
 *
 * @author iulian
 */
public class MultilineHeaderRenderer extends JPanel implements TableCellRenderer {
    private JHeaderSorterIcons iconProvider;

    JList dataList;
    JLabel iconLabel;

    private static Color bgColor = Color.WHITE;
    private static Color fgColor = Color.BLACK;

  public MultilineHeaderRenderer() {
    super();

    dataList = new JList();
    dataList.setOpaque(true);
    dataList.setForeground(fgColor);
    dataList.setBackground(bgColor);
    ListCellRenderer renderer = dataList.getCellRenderer();
    ((JLabel)renderer).setHorizontalAlignment(JLabel.CENTER);
    dataList.setCellRenderer(renderer);

    //Aici se va afisa iconul
    iconLabel = new JLabel();
    iconLabel.setOpaque(true);
    iconLabel.setForeground(fgColor);
    iconLabel.setBackground(bgColor);

    //Obtin icoanele
    iconProvider = new JHeaderSorterIcons();

    //Setez si JPanelul
    this.setOpaque(true);
    this.setForeground(fgColor);
    this.setBackground(bgColor);

    this.setLayout(new BorderLayout());
    this.setBorder(UIManager.getBorder("TableHeader.cellBorder"));

    this.add(dataList,BorderLayout.CENTER);
    this.add(iconLabel,BorderLayout.EAST);
  }

  public Component getTableCellRendererComponent(JTable table, Object value,
                   boolean isSelected, boolean hasFocus, int row, int column) {
    setFont(table.getFont());
    String str = (value == null) ? "" : value.toString();
    BufferedReader br = new BufferedReader(new StringReader(str));
    String line;
    Vector v = new Vector();
    try {
      while ((line = br.readLine()) != null) {
        v.addElement(line);
      }
    } catch (IOException ex) {
      ex.printStackTrace();
    }
    dataList.setListData(v);

    Icon icon;
    //Check if needs sorting
    boolean isSorted = false;
    if (table.getRowSorter() != null) {
        RowSorter sorter = table.getRowSorter();
        List sortKeys = sorter.getSortKeys();
        Iterator sortIterator = sortKeys.iterator();
        if (sortIterator.hasNext()) {
            RowSorter.SortKey key = (RowSorter.SortKey) sortIterator.next();
            if (key.getColumn() == column) {
                switch (key.getSortOrder()) {
                    case ASCENDING:
                        icon = iconProvider.getIcon(JHeaderSorterIcons.ASC);
                        iconLabel.setIcon(icon);
                        isSorted = true;
                        break;
                    case DESCENDING:
                        icon = iconProvider.getIcon(JHeaderSorterIcons.DESC);
                        iconLabel.setIcon(icon);
                        isSorted = true;
                        break;
                    default:
                        break;
                }
            }
        }
    }
    if (!isSorted) iconLabel.setIcon(null);


    return this;
    
    
  }
}

==> GenomeARTIST_v1.19_src.zip: src/exenne/components/headerrenderer/MultilineHeaderRenderer.java <==
/*
 * To change this template, choose Tools | Templates
 * and open the template in the editor.
 */

package exenne.components.headerrenderer;

import java.awt.BorderLayout;
import java.awt.Color;
import java.awt.Component;
import java.io.BufferedReader;
import java.io.IOException;
import java.io.StringReader;
import java.util.Iterator;
import java.util.List;
import java.util.Vector;
import javax.swing.Icon;
import javax.swing.JLabel;
import javax.swing.JList;
import javax.swing.JPanel;
import javax.swing.JTable;
import javax.swing.ListCellRenderer;
import javax.swing.RowSorter;
import javax.swing.UIManager;
import javax.swing.table.TableCellRenderer;

/**
 *
 * @author iulian
 */
public class MultilineHeaderRenderer extends JPanel implements TableCellRenderer {
    JList dataList;
    JLabel iconLabel;

    private static Color bgColor = Color.WHITE;
    private static Color fgColor = Color.BLACK;

  public MultilineHeaderRenderer() {
    super();

    dataList = new JList();
    dataList.setOpaque(true);
    dataList.setForeground(fgColor);
    dataList.setBackground(bgColor);
    ListCellRenderer renderer = dataList.getCellRenderer();
    ((JLabel)renderer).setHorizontalAlignment(JLabel.CENTER);
    dataList.setCellRenderer(renderer);

    //Aici se va afisa iconul
    iconLabel = new JLabel();
    iconLabel.setOpaque(true);
    iconLabel.setForeground(fgColor);
    iconLabel.setBackground(bgColor);

    //Setez si JPanelul
    this.setOpaque(true);
    this.setForeground(fgColor);
    this.setBackground(bgColor);

    this.setLayout(new BorderLayout());
    this.setBorder(UIManager.getBorder("TableHeader.cellBorder"));

    this.add(dataList,BorderLayout.CENTER);
    this.add(iconLabel,BorderLayout.EAST);
  }

  public Component getTableCellRendererComponent(JTable table, Object value,
                   boolean isSelected, boolean hasFocus, int row, int column) {
    setFont(table.getFont());
    String str = (value == null) ? "" : value.toString();
    BufferedReader br = new BufferedReader(new StringReader(str));
    String line;
    Vector v = new Vector();
    try {
      while ((line = br.readLine()) != null) {
        v.addElement(line);
      }
    } catch (IOException ex) {
      ex.printStackTrace();
    }
    dataList.setListData(v);

    Icon icon;
    //Check if needs sorting
    boolean isSorted = false;
    if (table.getRowSorter() != null) {
        RowSorter sorter = table.getRowSorter();
        List sortKeys = sorter.getSortKeys();
        Iterator sortIterator = sortKeys.iterator();
        if (sortIterator.hasNext()) {
            RowSorter.SortKey key = (RowSorter.SortKey) sortIterator.next();
            if (key.getColumn() == column) {
                switch (key.getSortOrder()) {
                    case ASCENDING:
                        icon = JHeaderSorterIcons.ASC.getIcon();
                        iconLabel.setIcon(icon);
                        isSorted = true;
                        break;
                    case DESCENDING:
                        icon = JHeaderSorterIcons.DESC.getIcon();
                        iconLabel.setIcon(icon);
                        isSorted = true;
                        break;
                    default:
                        break;
                }
            }
        }
    }
    if (!isSorted) iconLabel.setIcon(null);


    return this;
    
    
  }
}
